@@ -3,6 +3,7 @@ import sys
 class FlagManager:
     flags = []
     args = []
+    helpDiscription="Set helpDiscription to change this text"
     def __init__(self,flags=[]):
         self.flags = flags
         self.args = sys.argv
@@ -21,7 +22,7 @@ class FlagManager:
                 return flag
         return "ingen stämde"
 
-    def start(self):
+    def check(self):
         reading = False
         flagArgs = []
         index = 0
@@ -41,15 +42,20 @@ class FlagManager:
                 
         #print(index)
         currentFlag.onCall(flagArgs)
-        
+    
+    def printHelp(self):
+        print(self.helpDiscription)
+        for flag in self.flags:
+            print(flag)
 
 
 class Flag:
-    shortFlag = ""
-    longFlag = ""
-    
+    shortFlag = "t"
+    longFlag = "test"
+    discription = "This is a test text. Here you should write the discription if the flag"
+
     def onCall(self,args):
-        pass
+        print("Flag test was called")
 
     def __str__(self):
-        return "short-"+self.shortFlag+"  long--"+self.longFlag
+        return "-"+self.shortFlag+" --"+self.longFlag+"    "+self.discription
